@@ -30,11 +30,16 @@ sub do_system {
 
 sub verify_bin {
     my $bin = shift;
+    my $try = shift;
     for my $label (keys %$bin) {
         my @look_for = (ref $bin->{$label} eq 'ARRAY' ? @{ $bin->{$label} } : $bin->{$label});
         my $found;
         for my $potential_cmd (@look_for) {
-            last if ($found = qx[which $potential_cmd 2>/dev/null]);
+            last if $found = qx[which $potential_cmd];
+            if(defined $try && -x "$try/$potential_cmd") {
+                $found = "$try/$potential_cmd";
+                last;
+            }
         }
         unless ($found) {
             warn "could not find ".(join " or ",@look_for)." in current path\n" unless $label =~ /doc/;
